疯狂动物城 (豆瓣)
Description: 疯狂动物城电影简介和剧情介绍,疯狂动物城影评、图片、预告片、影讯、论坛、在线购票
Keywords: 疯狂动物城,Zootopia,疯狂动物城影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.18豆瓣电影Top250

# 疯狂动物城 Zootopia (2016)

更新描述或海报

导演: 拜伦·霍华德 / 瑞奇·摩尔 / 杰拉德·布什
编剧: 拜伦·霍华德 / 瑞奇·摩尔 / 杰拉德·布什 / 吉姆·里尔顿 / 乔西·特立尼达 / 菲尔·约翰斯顿 / 珍妮弗·李
主演: 金妮弗·古德温 / 杰森·贝特曼 / 伊德里斯·艾尔巴 / 珍妮·斯蕾特 / 内特·托伦斯 / 邦尼·亨特 / 唐·雷克 / 汤米·钟 / J·K·西蒙斯 / 奥克塔维亚·斯宾瑟 / 艾伦·图代克 / 夏奇拉 / 雷蒙德·S·佩尔西 / 德拉·萨巴 / 莫里斯·拉马奇 / 菲尔·约翰斯顿 / 约翰·迪·马吉欧 / 凯蒂·洛斯 / 吉塔·雷迪 / 杰西·科尔蒂 / 汤米·利斯特 / 乔希·达拉斯 / 瑞奇·摩尔 / 凯斯·索西 / 彼得·曼斯布里奇 / 拜伦·霍华德 / 杰拉德·布什 / 马克·史密斯 / 乔西·特立尼达 / 约翰·拉维尔 / 克里斯汀·贝尔 / 吉尔·科德斯 / 梅利莎·古德温
类型: 喜剧 / 动画 / 冒险
制片国家/地区: 美国
语言: 英语 / 挪威语
上映日期: 2016-03-04(中国大陆/美国) / 2020-07-24(中国大陆重映)
片长: 109分钟(中国大陆) / 108分钟
又名: 优兽大都会(港) / 动物方城市(台) / 动物乌托邦 / 动物大都会 / Zootropolis
IMDb: tt2948356
豆瓣评分
引用
9.2
1816214人评价
5星
65.9%
4星
29.3%
3星
4.5%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.0
4人评价
好于 99% 喜剧片
好于 99% 动画片
我看过这部电影 2021-05-20 修改
我的评价:
推荐

## 疯狂动物城的剧情简介 · · · · · ·

故事发生在一个所有哺乳类动物和谐共存的美好世界中，兔子朱迪（金妮弗·古德温 Ginnifer Goodwin 配音）从小就梦想着能够成为一名惩恶扬善的刑警，凭借着智慧和努力，朱迪成功的从警校中毕业进入了疯狂动物城警察局，殊不知这里是大型肉食类动物的领地，作为第一只，也是唯一的小型食草类动物，朱迪会遇到怎样的故事呢？
近日里，城中接连发生动物失踪案件，就在全部警员都致力于调查案件真相之时，朱迪却被局长（伊德瑞斯·艾尔巴 Idris Elba 配音）发配成为了一名无足轻重的交警。某日，正在执勤的兔子遇见了名为尼克（杰森·贝特曼 Jason Bateman 配音）的狐狸，两人不打不相识，之后又误打误撞的接受了寻找失踪的水獭先生的任务，如果不能在两天之内找到水獭先生，朱迪就必须自愿离开警局。朱迪找到了尼克，两人联手揭露了一个隐藏在疯狂动物城之中的惊天秘密。 ©豆瓣

## 疯狂动物城的演职员 · · · · · · ( 全部 56 )

- 拜伦·霍华德 导演
- 瑞奇·摩尔 导演
- 金妮弗·古德温 配 兔朱迪 Judy Hopps
- 杰森·贝特曼 配 狐尼克 Nick Wilde
- 伊德里斯·艾尔巴 配 牛局长 Chief Bogo
- 珍妮·斯蕾特 配 羊副市长 Bellwether

## 疯狂动物城的视频和图片 · · · · · · ( 预告片20 | 添加视频评论 | 图片1916 · 添加 )

## 疯狂动物城的获奖情况 · · · · · · ( 全部 )

- 第89届奥斯卡金像奖
- 最佳动画长片
- 拜伦·霍华德 / 瑞奇·摩尔 / 克拉克·斯宾塞

- 第74届金球奖
- 电影类 最佳动画长片

- 第70届英国电影学院奖
- 电影奖 最佳动画片(提名)
- 拜伦·霍华德 / 瑞奇·摩尔

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  哈尔的移动城堡

  大闹天宫

  幽灵公主

  千与千寻

  神偷奶爸

  怪兽电力公司

  风之谷

  玩具总动员

  魔女宅急便

我要写短评

## 疯狂动物城的短评 · · · · · · ( 全部 370152 条 )

热门 / 最新 / 好友

### 11582 有用 祥林嫂 看过 2016-03-02 11:18:56

树懒太他妈好笑了！！那两分钟我嗓子都哑了！！卧槽！！真是太他妈好笑了！！

### 9973 有用 悄悄 看过 2016-03-01 16:55:31

看过了这一部，我好像能够更坚定地说我会当迪士尼一辈子的粉丝。迪士尼给我们营造的乌托邦就是这样，永远善良勇敢，永远出乎意料。

### 7690 有用 吴杲杲 看过 2016-02-26 04:20:45

无论是人设，世界观，动画制作，还是剧本，都挑不出毛病来啊啊啊！！细节多到爆！！好幸福！！！！>w< 最难能可贵的是配角们的人物性格和形象设置都非常饱满（教父梗好惊喜>< ） 虽然是动画，但是剧本还是隐射很多人类社会的种族问题，以及政治两党上位之争的问题。另外我狐Nick的眼神是在太苏了TwT...

### 6257 有用 影评终结者 看过 2016-02-26 10:28:40

完爆冰雪超能头脑，动物再次证明了动画片不止是给小朋友看的，而是全年龄段和世界级的，尖端数码特技、新意剧情、老梗新用搭配萌Q画风，乌托励志、搞笑温情、自然销魂、阴谋反转，用动物来映射人类，涉及种族歧视和两党斗争，无论从制作技术还是政治倾向或是社会意义来说，基本锁定今年奥斯卡最佳动画

### 5382 有用 黄青蕉 看过 2016-03-07 20:47:43

港真，面对人家动画片里连一把椅子扶手上的铝合金划痕都做得活灵活现的态度，咱们就默默低头学就好，不要一天到晚吹“国产视效大片”这个概念了，略尴尬

> 更多短评 370152条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:37:08

政治就是不断的制造事端。

我要写影评

## 疯狂动物城的影评 · · · · · · ( 全部 4136 条 )

热门 / 最新 / 好友
CydenyLau 2016-02-27 17:51:58

## 【C+影评】疯狂动物城：政治正确的美丽新世界

作为迪士尼少有的春季档动画，《疯狂动物城》所展现出来的意识和状态完全不是一部动画电影该有的样子。 In a GREAT way. 自2008年的《闪电狗》以来，有了皮克斯大只佬约翰·拉塞特的倾力执掌，新世代的迪士尼动画展现出非凡的进步与成就。2012年的《无敌破坏王》，2013年的《冰... (展开)
6404 742 365回应 收起
Vamei 2016-03-04 09:27:50

## 《疯狂动物城》的三重内涵，以及一个文化图腾的诞生

电影结束时已是深夜。影院中的观众都不愿离开，坐在椅子上听着片尾曲“Try Everything”，随着超强的节奏摇头晃脑。我沉浸在相同的气氛中，不断回味着电影带来的震撼。这部电影有近年来成功动画的因素：《冰川时代》的搞笑，《驯龙高手》的成长，《超能陆战队》的治愈。但《疯... (展开)
4639 545 229回应 收起
我是卢俊 2016-03-04 07:42:42

## 孩子：学会做一个体面的普通人

前言：很多家长，如果今明两天不带孩子去看，就可能错过人生他们人生中最重要的周末，迪士尼数千个创意者为孩子们准备的最好的一个世界，是我们身边所有父母不可能建构的，一个平行于人类成人世界最好的寓言。目前，排片率并不高，而且竞争对手大肆刷票房，这种事迪士尼这样的... (展开)
2807 344 281回应 收起
柴斯卡 2016-03-11 17:37:12

## 疯狂动物城的阴暗面

概括下：大麻王亲自配音、地下黑市尺度猖獗、车管所公务员涉嫌腐败、为什么黑老大的车上有鼠帮的CD以及狐狸和兔子的生活都不太浪漫。有些说我恶意推测的，醉了，你的世界是心灵鸡汤熬的么？这个片子人物这么扎实是有原因的，它的魅力就在于我们很少见到主流动画影片中有这么复... (展开)
1973 459 292回应 收起
张腾森 2016-03-04 15:56:57

## 这是一部让我变成水军的动画

烂番茄新鲜度100%，豆瓣评分9.2，用逆天来形容这部迪士尼动画毫不为过。无论你是为了陪伴孩子，还是单纯放松娱乐，甚至是想要反思现代社会，《疯狂动物城》都是这个春天最好的选择。它的想象力天马行空，它的笑点俯拾即是，它的寓言性深刻隽永。这是一部把我变成水军的动画片，... (展开)
2203 362 146回应 收起
猫饼干 2016-03-08 15:44:54

## 比起公主电影，这部动画更适合女孩子看

《疯狂动物城》乍一看是个卖萌片。最开始，我是被兔子毛绒绒的耳朵吸引去看的。毛绒绒软绵绵的小动物，谁会不喜欢呢？ 一心想要成为警察的兔子，从小被人说着“哪有兔子能当警察”，还是义无反顾地到了动物城。她相信着在这座城市里，任何人都有平等地实现梦想... (展开)
1558 92 189回应 收起
阑夕 2016-03-10 18:16:25

## 疯狂动物城：三个谎言和一个事实

文 | 阑夕（微信公众帐号：techread） 很久没有看到这样“零差评”的动画电影了，就像现在称赞美女一定要加上“零死角”的定语一样，这个世界上素来不会缺少苛刻挑剔的批评家，却罕见让非议荡然无存的干净回敬。 尤其值得一提的是，这部出产于迪士尼的第55部动画长片，本身已... (展开)
1275 77 132回应 收起
野象小姐 2016-03-10 10:55:27

## 狐狸，肉麻恐惧症的福音：“当痞子突然认真的时候。”

这篇影评可能有剧透

作为一个严重的肉麻恐惧症患者，害怕一切犯尴尬症的感情。看完《疯狂动物城》狐狸与兔子的CP总算明白： 好爱情，是不矫情不腻歪，不是非得叫对方baby。是既可以携手打天下，又可以脑袋抵在对方胸口恸哭，站在晨光熹微的电缆上聊一聊小时候的难堪，是保护彼此的愚蠢梦想，是毫... (展开)
1411 173 127回应 收起
水湄物语 2016-03-11 15:17:50

## 天杀的编剧，你扼杀了一个商业奇才！

当然，当然。男友力爆棚！ 当然，当然，树懒很好笑！ 但是，真的只有我一个人对结局不满意么？ 让我们来看下。 狐狸和他的搭档（那是什么动物来着），去大象冰淇淋店买了一只超大的棒冰，成本是15美元。 在这件事上，大象对他有偏见，不肯卖他，但他并没有弄虚作假。 然后他... (展开)
842 135 155回应 收起
德小科 2016-03-07 18:39:58

## Zootopia与它的社会学彩蛋

这篇影评可能有剧透

文 | 德小科 欢迎关注个人公众号 | Escapetome 赶在二刷结束，趁热打铁回来赶紧写点什么。其实在上映第一天看完之后就已经心绪难平、感慨万千，但是苦于周末有各种死线以及海外友人来访，没来得及整理。今天二刷，果真发现了第一次看中许多没留意的小细节，又是一次无比惊喜的... (展开)
1019 56 62回应 收起

> 更多影评 4136篇

添加新讨论

## 讨论区 · · · · · ·

疯狂动物城 | 来自李子维 |  | 2022-11-24 16:29:50
想知道还有没有和疯狂动物城类似的电影 | 来自捣蛋荷包蛋 | 2 回应 | 2022-11-23 15:15:25
动物城里的肉食动物都吃什么肉？ | 来自黎 何 段 程 | 1 回应 | 2022-11-20 10:31:58
这部电影是在映射这个主题，对吧 | 来自丁酉戊戌 | 4 回应 | 2022-11-18 19:51:30
对尼克心动 | 来自旺仔宝宝 |  | 2022-11-18 19:45:27

> 去这部影片的讨论区（全部533条）

## 关于《疯狂动物城》的问题 · · · · · · ( 全部266个 )

- 突然想到一个可能存在的bug:那些食肉动物吃什么←_←？ 51人回答
- 他们为什么知道羊会射狐狸？ 50人回答

> 全部266个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 治愈系动画推荐 ([己注销])
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 10分钟就让你【欲罢不能】的高分电影 (梭马飞鱼)

## 谁在看这部电影 · · · · · ·

- 原野的夏天
  刚刚 看过
- 初见
  刚刚 看过
- 💗
  2分钟前 看过

3526383人看过 / 156002人想看

订阅疯狂动物城的评论:
feed: rss 2.0